@@ -8,6 +8,7 @@ from narwhals._compliant import CompliantSelector, EagerSelectorNamespace
 if TYPE_CHECKING:
     from narwhals._arrow.dataframe import ArrowDataFrame  # noqa: F401
     from narwhals._arrow.series import ArrowSeries  # noqa: F401
+    from narwhals._compliant.typing import ScalarKwargs
 
 
 class ArrowSelectorNamespace(EagerSelectorNamespace["ArrowDataFrame", "ArrowSeries"]):
@@ -17,6 +18,10 @@ class ArrowSelectorNamespace(EagerSelectorNamespace["ArrowDataFrame", "ArrowSeri
 
 
 class ArrowSelector(CompliantSelector["ArrowDataFrame", "ArrowSeries"], ArrowExpr):  # type: ignore[misc]
+    _depth: int = 0
+    _scalar_kwargs: ScalarKwargs = {}  # noqa: RUF012
+    _function_name: str = "selector"
+
     def _to_expr(self) -> ArrowExpr:
         return ArrowExpr(
             self._call,
@@ -24,6 +29,5 @@ class ArrowSelector(CompliantSelector["ArrowDataFrame", "ArrowSeries"], ArrowExp
             function_name=self._function_name,
             evaluate_output_names=self._evaluate_output_names,
             alias_output_names=self._alias_output_names,
-            backend_version=self._backend_version,
             version=self._version,
         )
