@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import abc
 from functools import lru_cache
-from typing import TYPE_CHECKING, Any, ClassVar, Protocol, TypeVar, overload
+from typing import TYPE_CHECKING, Any, ClassVar, Final, Protocol, TypeVar, overload
 
 import polars as pl
 
@@ -30,10 +30,10 @@ if TYPE_CHECKING:
 
     from typing_extensions import TypeIs
 
+    from narwhals._compliant.typing import Accessor
     from narwhals._polars.dataframe import Method
     from narwhals._polars.expr import PolarsExpr
     from narwhals._polars.series import PolarsSeries
-    from narwhals._polars.typing import NativeAccessor
     from narwhals.dtypes import DType
     from narwhals.typing import IntoDType
 
@@ -49,6 +49,24 @@ CompliantT = TypeVar("CompliantT", "PolarsSeries", "PolarsExpr")
 BACKEND_VERSION = Implementation.POLARS._backend_version()
 """Static backend version for `polars`."""
 
+SERIES_ACCEPTS_PD_INDEX: Final[bool] = BACKEND_VERSION >= (0, 20, 7)
+"""`pl.Series(values: pd.Index)` fixed in https://github.com/pola-rs/polars/pull/14087"""
+
+SERIES_RESPECTS_DTYPE: Final[bool] = BACKEND_VERSION >= (0, 20, 26)
+"""`pl.Series(dtype=...)` fixed in https://github.com/pola-rs/polars/pull/15962
+
+Includes `SERIES_ACCEPTS_PD_INDEX`.
+"""
+
+HAS_INT_128 = BACKEND_VERSION >= (1, 18, 0)
+"""https://github.com/pola-rs/polars/pull/20232"""
+
+FROM_DICTS_ACCEPTS_MAPPINGS: Final[bool] = BACKEND_VERSION >= (1, 30, 0)
+"""`pl.from_dicts(data: Iterable[Mapping[str, Any]])` since https://github.com/pola-rs/polars/pull/22638"""
+
+HAS_UINT_128 = BACKEND_VERSION >= (1, 34, 0)
+"""https://github.com/pola-rs/polars/pull/24346"""
+
 
 @overload
 def extract_native(obj: _StoresNative[NativeT]) -> NativeT: ...
@@ -84,8 +102,7 @@ def native_to_narwhals_dtype(  # noqa: C901, PLR0912
         return dtypes.Float64()
     if dtype == pl.Float32:
         return dtypes.Float32()
-    if hasattr(pl, "Int128") and dtype == pl.Int128:  # pragma: no cover
-        # Not available for Polars pre 1.8.0
+    if HAS_INT_128 and dtype == pl.Int128:
         return dtypes.Int128()
     if dtype == pl.Int64:
         return dtypes.Int64()
@@ -95,8 +112,7 @@ def native_to_narwhals_dtype(  # noqa: C901, PLR0912
         return dtypes.Int16()
     if dtype == pl.Int8:
         return dtypes.Int8()
-    if hasattr(pl, "UInt128") and dtype == pl.UInt128:  # pragma: no cover
-        # Not available for Polars pre 1.8.0
+    if HAS_UINT_128 and dtype == pl.UInt128:
         return dtypes.UInt128()
     if dtype == pl.UInt64:
         return dtypes.UInt64()
@@ -153,41 +169,47 @@ def native_to_narwhals_dtype(  # noqa: C901, PLR0912
     return dtypes.Unknown()
 
 
-def narwhals_to_native_dtype(  # noqa: C901, PLR0912
+dtypes = Version.MAIN.dtypes
+
+
+def _version_dependent_dtypes() -> dict[type[DType], pl.DataType]:
+    if not HAS_INT_128:  # pragma: no cover
+        return {}
+    nw_to_pl: dict[type[DType], pl.DataType] = {dtypes.Int128: pl.Int128()}
+    return nw_to_pl | {dtypes.UInt128: pl.UInt128()} if HAS_UINT_128 else nw_to_pl
+
+
+NW_TO_PL_DTYPES: Mapping[type[DType], pl.DataType] = {
+    dtypes.Float64: pl.Float64(),
+    dtypes.Float32: pl.Float32(),
+    dtypes.Binary: pl.Binary(),
+    dtypes.String: pl.String(),
+    dtypes.Boolean: pl.Boolean(),
+    dtypes.Categorical: pl.Categorical(),
+    dtypes.Date: pl.Date(),
+    dtypes.Time: pl.Time(),
+    dtypes.Int8: pl.Int8(),
+    dtypes.Int16: pl.Int16(),
+    dtypes.Int32: pl.Int32(),
+    dtypes.Int64: pl.Int64(),
+    dtypes.UInt8: pl.UInt8(),
+    dtypes.UInt16: pl.UInt16(),
+    dtypes.UInt32: pl.UInt32(),
+    dtypes.UInt64: pl.UInt64(),
+    dtypes.Object: pl.Object(),
+    dtypes.Unknown: pl.Unknown(),
+    **_version_dependent_dtypes(),
+}
+UNSUPPORTED_DTYPES = (dtypes.Decimal,)
+
+
+def narwhals_to_native_dtype(  # noqa: C901
     dtype: IntoDType, version: Version
 ) -> pl.DataType:
     dtypes = version.dtypes
-    if dtype == dtypes.Float64:
-        return pl.Float64()
-    if dtype == dtypes.Float32:
-        return pl.Float32()
-    if dtype == dtypes.Int128 and hasattr(pl, "Int128"):
-        # Not available for Polars pre 1.8.0
-        return pl.Int128()
-    if dtype == dtypes.Int64:
-        return pl.Int64()
-    if dtype == dtypes.Int32:
-        return pl.Int32()
-    if dtype == dtypes.Int16:
-        return pl.Int16()
-    if dtype == dtypes.Int8:
-        return pl.Int8()
-    if dtype == dtypes.UInt64:
-        return pl.UInt64()
-    if dtype == dtypes.UInt32:
-        return pl.UInt32()
-    if dtype == dtypes.UInt16:
-        return pl.UInt16()
-    if dtype == dtypes.UInt8:
-        return pl.UInt8()
-    if dtype == dtypes.String:
-        return pl.String()
-    if dtype == dtypes.Boolean:
-        return pl.Boolean()
-    if dtype == dtypes.Object:  # pragma: no cover
-        return pl.Object()
-    if dtype == dtypes.Categorical:
-        return pl.Categorical()
+    base_type = dtype.base_type()
+    if pl_type := NW_TO_PL_DTYPES.get(base_type):
+        return pl_type
     if isinstance_or_issubclass(dtype, dtypes.Enum):
         if version is Version.V1:
             msg = "Converting to Enum is not supported in narwhals.stable.v1"
@@ -196,15 +218,6 @@ def narwhals_to_native_dtype(  # noqa: C901, PLR0912
             return pl.Enum(dtype.categories)
         msg = "Can not cast / initialize Enum without categories present"
         raise ValueError(msg)
-    if dtype == dtypes.Date:
-        return pl.Date()
-    if dtype == dtypes.Time:
-        return pl.Time()
-    if dtype == dtypes.Binary:
-        return pl.Binary()
-    if dtype == dtypes.Decimal:
-        msg = "Casting to Decimal is not supported yet."
-        raise NotImplementedError(msg)
     if isinstance_or_issubclass(dtype, dtypes.Datetime):
         return pl.Datetime(dtype.time_unit, dtype.time_zone)  # type: ignore[arg-type]
     if isinstance_or_issubclass(dtype, dtypes.Duration):
@@ -221,6 +234,9 @@ def narwhals_to_native_dtype(  # noqa: C901, PLR0912
         size = dtype.size
         kwargs = {"width": size} if BACKEND_VERSION < (0, 20, 30) else {"shape": size}
         return pl.Array(narwhals_to_native_dtype(dtype.inner, version), **kwargs)
+    if issubclass(base_type, UNSUPPORTED_DTYPES):
+        msg = f"Converting to {base_type.__name__} dtype is not supported for Polars."
+        raise NotImplementedError(msg)
     return pl.Unknown()  # pragma: no cover
 
 
@@ -259,7 +275,7 @@ class PolarsAnyNamespace(
     _StoresNative[NativeT_co],
     Protocol[CompliantT_co, NativeT_co],
 ):
-    _accessor: ClassVar[NativeAccessor]
+    _accessor: ClassVar[Accessor]
 
     def __getattr__(self, attr: str) -> Callable[..., CompliantT_co]:
         def func(*args: Any, **kwargs: Any) -> CompliantT_co:
@@ -271,7 +287,7 @@ class PolarsAnyNamespace(
 
 
 class PolarsDateTimeNamespace(PolarsAnyNamespace[CompliantT, NativeT_co]):
-    _accessor: ClassVar[NativeAccessor] = "dt"
+    _accessor: ClassVar[Accessor] = "dt"
 
     def truncate(self, every: str) -> CompliantT:
         # Ensure consistent error message is raised.
@@ -307,7 +323,7 @@ class PolarsDateTimeNamespace(PolarsAnyNamespace[CompliantT, NativeT_co]):
 
 
 class PolarsStringNamespace(PolarsAnyNamespace[CompliantT, NativeT_co]):
-    _accessor: ClassVar[NativeAccessor] = "str"
+    _accessor: ClassVar[Accessor] = "str"
 
     # NOTE: Use `abstractmethod` if we have defs to implement, but also `Method` usage
     @abc.abstractmethod
@@ -329,19 +345,21 @@ class PolarsStringNamespace(PolarsAnyNamespace[CompliantT, NativeT_co]):
 
 
 class PolarsCatNamespace(PolarsAnyNamespace[CompliantT, NativeT_co]):
-    _accessor: ClassVar[NativeAccessor] = "cat"
+    _accessor: ClassVar[Accessor] = "cat"
     get_categories: Method[CompliantT]
 
 
 class PolarsListNamespace(PolarsAnyNamespace[CompliantT, NativeT_co]):
-    _accessor: ClassVar[NativeAccessor] = "list"
+    _accessor: ClassVar[Accessor] = "list"
 
     @abc.abstractmethod
     def len(self) -> CompliantT: ...
 
+    get: Method[CompliantT]
+
     unique: Method[CompliantT]
 
 
 class PolarsStructNamespace(PolarsAnyNamespace[CompliantT, NativeT_co]):
-    _accessor: ClassVar[NativeAccessor] = "struct"
+    _accessor: ClassVar[Accessor] = "struct"
     field: Method[CompliantT]
