@@ -1,12 +1,13 @@
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Any, Iterable, NoReturn
+from typing import TYPE_CHECKING, Any, NoReturn
 
 from narwhals._expression_parsing import ExprMetadata, combine_metadata
+from narwhals._utils import flatten
 from narwhals.expr import Expr
-from narwhals.utils import flatten
 
 if TYPE_CHECKING:
+    from collections.abc import Iterable
     from datetime import timezone
 
     from narwhals.dtypes import DType
@@ -67,9 +68,6 @@ def by_dtype(*dtypes: DType | type[DType] | Iterable[DType | type[DType]]) -> Se
     Arguments:
         dtypes: one or data types to select
 
-    Returns:
-        A new expression.
-
     Examples:
         >>> import pyarrow as pa
         >>> import narwhals as nw
@@ -100,9 +98,6 @@ def matches(pattern: str) -> Selector:
     Arguments:
         pattern: A valid regular expression pattern.
 
-    Returns:
-        A new expression.
-
     Examples:
         >>> import pandas as pd
         >>> import narwhals as nw
@@ -127,9 +122,6 @@ def matches(pattern: str) -> Selector:
 def numeric() -> Selector:
     """Select numeric columns.
 
-    Returns:
-        A new expression.
-
     Examples:
         >>> import polars as pl
         >>> import narwhals as nw
@@ -158,9 +150,6 @@ def numeric() -> Selector:
 def boolean() -> Selector:
     """Select boolean columns.
 
-    Returns:
-        A new expression.
-
     Examples:
         >>> import polars as pl
         >>> import narwhals as nw
@@ -193,9 +182,6 @@ def boolean() -> Selector:
 def string() -> Selector:
     """Select string columns.
 
-    Returns:
-        A new expression.
-
     Examples:
         >>> import polars as pl
         >>> import narwhals as nw
@@ -224,9 +210,6 @@ def string() -> Selector:
 def categorical() -> Selector:
     """Select categorical columns.
 
-    Returns:
-        A new expression.
-
     Examples:
         >>> import polars as pl
         >>> import narwhals as nw
@@ -257,9 +240,6 @@ def categorical() -> Selector:
 def all() -> Selector:
     """Select all columns.
 
-    Returns:
-        A new expression.
-
     Examples:
         >>> import pandas as pd
         >>> import narwhals as nw
@@ -295,9 +275,6 @@ def datetime(
             * Set `None` to select Datetime columns that do not have a timezone.
             * Set `"*"` to select Datetime columns that have *any* timezone.
 
-    Returns:
-        A new expression.
-
     Examples:
         >>> from datetime import datetime, timezone
         >>> import pyarrow as pa
