@@ -12,9 +12,8 @@ from narwhals._namespace import (
     is_native_polars,
     is_native_spark_like,
 )
-from narwhals._utils import Version
+from narwhals._utils import Implementation, Version, has_native_namespace
 from narwhals.dependencies import (
-    get_dask,
     get_dask_expr,
     get_numpy,
     get_pandas,
@@ -35,9 +34,9 @@ if TYPE_CHECKING:
     from narwhals.series import Series
     from narwhals.typing import (
         DataFrameT,
+        Frame,
         IntoDataFrameT,
         IntoFrame,
-        IntoFrameT,
         IntoLazyFrameT,
         IntoSeries,
         IntoSeriesT,
@@ -57,8 +56,8 @@ def to_native(
 ) -> IntoDataFrameT: ...
 @overload
 def to_native(
-    narwhals_object: LazyFrame[IntoFrameT], *, pass_through: Literal[False] = ...
-) -> IntoFrameT: ...
+    narwhals_object: LazyFrame[IntoLazyFrameT], *, pass_through: Literal[False] = ...
+) -> IntoLazyFrameT: ...
 @overload
 def to_native(
     narwhals_object: Series[IntoSeriesT], *, pass_through: Literal[False] = ...
@@ -69,26 +68,15 @@ def to_native(narwhals_object: Any, *, pass_through: bool) -> Any: ...
 
 def to_native(
     narwhals_object: DataFrame[IntoDataFrameT]
-    | LazyFrame[IntoFrameT]
+    | LazyFrame[IntoLazyFrameT]
     | Series[IntoSeriesT],
     *,
-    strict: bool | None = None,
-    pass_through: bool | None = None,
-) -> IntoDataFrameT | IntoFrameT | IntoSeriesT | Any:
+    pass_through: bool = False,
+) -> IntoDataFrameT | IntoLazyFrameT | IntoSeriesT | Any:
     """Convert Narwhals object to native one.
 
     Arguments:
         narwhals_object: Narwhals object.
-        strict: Determine what happens if `narwhals_object` isn't a Narwhals class
-
-            - `True` (default): raise an error
-            - `False`: pass object through as-is
-
-            *Deprecated* (v1.13.0)
-
-            Please use `pass_through` instead. Note that `strict` is still available
-            (and won't emit a deprecation warning) if you use `narwhals.stable.v1`,
-            see [perfect backwards compatibility policy](../backcompat.md/).
         pass_through: Determine what happens if `narwhals_object` isn't a Narwhals class
 
             - `False` (default): raise an error
@@ -97,14 +85,9 @@ def to_native(
     Returns:
         Object of class that user started with.
     """
-    from narwhals._utils import validate_strict_and_pass_though
     from narwhals.dataframe import BaseFrame
     from narwhals.series import Series
 
-    pass_through = validate_strict_and_pass_though(
-        strict, pass_through, pass_through_default=False, emit_deprecation_warning=True
-    )
-
     if isinstance(narwhals_object, BaseFrame):
         return narwhals_object._compliant_frame._native_frame
     if isinstance(narwhals_object, Series):
@@ -185,13 +168,13 @@ def from_native(
 
 @overload
 def from_native(
-    native_object: IntoFrameT | IntoLazyFrameT | IntoSeriesT,
+    native_object: IntoDataFrameT | IntoLazyFrameT | IntoSeriesT,
     *,
     pass_through: Literal[True],
     eager_only: Literal[False] = ...,
     series_only: Literal[False] = ...,
     allow_series: Literal[True],
-) -> DataFrame[IntoFrameT] | LazyFrame[IntoLazyFrameT] | Series[IntoSeriesT]: ...
+) -> DataFrame[IntoDataFrameT] | LazyFrame[IntoLazyFrameT] | Series[IntoSeriesT]: ...
 
 
 @overload
@@ -205,11 +188,8 @@ def from_native(
 ) -> Series[IntoSeriesT]: ...
 
 
-# NOTE: Seems like `mypy` is giving a false positive
-# Following this advice will introduce overlapping overloads?
-# > note: Flipping the order of overloads will fix this error
 @overload
-def from_native(  # type: ignore[overload-overlap]
+def from_native(
     native_object: IntoLazyFrameT,
     *,
     pass_through: Literal[False] = ...,
@@ -276,15 +256,19 @@ def from_native(
 
 
 def from_native(  # noqa: D417
-    native_object: IntoLazyFrameT | IntoFrameT | IntoSeriesT | IntoFrame | IntoSeries | T,
+    native_object: IntoLazyFrameT
+    | IntoDataFrameT
+    | IntoSeriesT
+    | IntoFrame
+    | IntoSeries
+    | T,
     *,
-    strict: bool | None = None,
-    pass_through: bool | None = None,
+    pass_through: bool = False,
     eager_only: bool = False,
     series_only: bool = False,
     allow_series: bool | None = None,
     **kwds: Any,
-) -> LazyFrame[IntoLazyFrameT] | DataFrame[IntoFrameT] | Series[IntoSeriesT] | T:
+) -> LazyFrame[IntoLazyFrameT] | DataFrame[IntoDataFrameT] | Series[IntoSeriesT] | T:
     """Convert `native_object` to Narwhals Dataframe, Lazyframe, or Series.
 
     Arguments:
@@ -294,19 +278,9 @@ def from_native(  # noqa: D417
             - a Dataframe / Lazyframe / Series supported by Narwhals (pandas, Polars, PyArrow, ...)
             - an object which implements `__narwhals_dataframe__`, `__narwhals_lazyframe__`,
               or `__narwhals_series__`
-        strict: Determine what happens if the object can't be converted to Narwhals
-
-            - `True` or `None` (default): raise an error
-            - `False`: pass object through as-is
-
-            *Deprecated* (v1.13.0)
-
-            Please use `pass_through` instead. Note that `strict` is still available
-            (and won't emit a deprecation warning) if you use `narwhals.stable.v1`,
-            see [perfect backwards compatibility policy](../backcompat.md/).
         pass_through: Determine what happens if the object can't be converted to Narwhals
 
-            - `False` or `None` (default): raise an error
+            - `False` (default): raise an error
             - `True`: pass object through as-is
         eager_only: Whether to only allow eager objects
 
@@ -325,11 +299,6 @@ def from_native(  # noqa: D417
         DataFrame, LazyFrame, Series, or original object, depending
             on which combination of parameters was passed.
     """
-    from narwhals._utils import validate_strict_and_pass_though
-
-    pass_through = validate_strict_and_pass_though(
-        strict, pass_through, pass_through_default=False, emit_deprecation_warning=True
-    )
     if kwds:
         msg = f"from_native() got an unexpected keyword argument {next(iter(kwds))!r}"
         raise TypeError(msg)
@@ -356,12 +325,11 @@ def _from_native_impl(  # noqa: C901, PLR0911, PLR0912, PLR0915
     allow_series: bool | None = None,
     version: Version,
 ) -> Any:
+    from narwhals._interchange.dataframe import supports_dataframe_interchange
     from narwhals._utils import (
-        _supports_dataframe_interchange,
         is_compliant_dataframe,
         is_compliant_lazyframe,
         is_compliant_series,
-        parse_version,
     )
     from narwhals.dataframe import DataFrame, LazyFrame
     from narwhals.series import Series
@@ -391,7 +359,7 @@ def _from_native_impl(  # noqa: C901, PLR0911, PLR0912, PLR0915
         return version.dataframe(
             native_object.__narwhals_dataframe__()._with_version(version), level="full"
         )
-    elif is_compliant_lazyframe(native_object):
+    if is_compliant_lazyframe(native_object):
         if series_only:
             if not pass_through:
                 msg = "Cannot only use `series_only` with lazyframe"
@@ -405,7 +373,7 @@ def _from_native_impl(  # noqa: C901, PLR0911, PLR0912, PLR0915
         return version.lazyframe(
             native_object.__narwhals_lazyframe__()._with_version(version), level="full"
         )
-    elif is_compliant_series(native_object):
+    if is_compliant_series(native_object):
         if not allow_series:
             if not pass_through:
                 msg = "Please set `allow_series=True` or `series_only=True`"
@@ -416,7 +384,7 @@ def _from_native_impl(  # noqa: C901, PLR0911, PLR0912, PLR0915
         )
 
     # Polars
-    elif is_native_polars(native_object):
+    if is_native_polars(native_object):
         if series_only and not is_polars_series(native_object):
             if not pass_through:
                 msg = f"Cannot only use `series_only` with {type(native_object).__qualname__}"
@@ -441,7 +409,7 @@ def _from_native_impl(  # noqa: C901, PLR0911, PLR0912, PLR0915
         )
 
     # PandasLike
-    elif is_native_pandas_like(native_object):
+    if is_native_pandas_like(native_object):
         if is_pandas_like_dataframe(native_object):
             if series_only:
                 if not pass_through:
@@ -460,7 +428,7 @@ def _from_native_impl(  # noqa: C901, PLR0911, PLR0912, PLR0915
         )
 
     # PyArrow
-    elif is_native_arrow(native_object):
+    if is_native_arrow(native_object):
         if is_pyarrow_table(native_object):
             if series_only:
                 if not pass_through:
@@ -479,9 +447,7 @@ def _from_native_impl(  # noqa: C901, PLR0911, PLR0912, PLR0915
         )
 
     # Dask
-    elif is_dask_dataframe(native_object):
-        from narwhals._dask.namespace import DaskNamespace
-
+    if is_dask_dataframe(native_object):
         if series_only:
             if not pass_through:
                 msg = "Cannot only use `series_only` with dask DataFrame"
@@ -492,18 +458,20 @@ def _from_native_impl(  # noqa: C901, PLR0911, PLR0912, PLR0915
                 msg = "Cannot only use `eager_only` or `eager_or_interchange_only` with dask DataFrame"
                 raise TypeError(msg)
             return native_object
-        dask_version = parse_version(get_dask())
-        if dask_version <= (2024, 12, 1) and get_dask_expr() is None:  # pragma: no cover
+        if (
+            Implementation.DASK._backend_version() <= (2024, 12, 1)
+            and get_dask_expr() is None
+        ):  # pragma: no cover
             msg = "Please install dask-expr"
             raise ImportError(msg)
         return (
-            DaskNamespace(backend_version=dask_version, version=version)
-            .from_native(native_object)
+            version.namespace.from_backend(Implementation.DASK)
+            .compliant.from_native(native_object)
             .to_narwhals()
         )
 
     # DuckDB
-    elif is_duckdb_relation(native_object):
+    if is_duckdb_relation(native_object):
         if eager_only or series_only:  # pragma: no cover
             if not pass_through:
                 msg = "Cannot only use `series_only=True` or `eager_only=False` with DuckDBPyRelation"
@@ -516,7 +484,7 @@ def _from_native_impl(  # noqa: C901, PLR0911, PLR0912, PLR0915
         )
 
     # Ibis
-    elif is_ibis_table(native_object):
+    if is_ibis_table(native_object):
         if eager_only or series_only:  # pragma: no cover
             if not pass_through:
                 msg = "Cannot only use `series_only=True` or `eager_only=False` with ibis.Table"
@@ -529,7 +497,7 @@ def _from_native_impl(  # noqa: C901, PLR0911, PLR0912, PLR0915
         )
 
     # PySpark
-    elif is_native_spark_like(native_object):  # pragma: no cover
+    if is_native_spark_like(native_object):  # pragma: no cover
         ns_spark = version.namespace.from_native_object(native_object)
         if series_only or eager_only or eager_or_interchange_only:
             if not pass_through:
@@ -542,7 +510,7 @@ def _from_native_impl(  # noqa: C901, PLR0911, PLR0912, PLR0915
         return ns_spark.compliant.from_native(native_object).to_narwhals()
 
     # Interchange protocol
-    elif _supports_dataframe_interchange(native_object):
+    if supports_dataframe_interchange(native_object):
         from narwhals._interchange.dataframe import InterchangeFrame
 
         if eager_only or series_only:
@@ -566,15 +534,13 @@ def _from_native_impl(  # noqa: C901, PLR0911, PLR0912, PLR0915
             raise TypeError(msg)
         return Version.V1.dataframe(InterchangeFrame(native_object), level="interchange")
 
-    elif not pass_through:
+    if not pass_through:
         msg = f"Expected pandas-like dataframe, Polars dataframe, or Polars lazyframe, got: {type(native_object)}"
         raise TypeError(msg)
     return native_object
 
 
-def get_native_namespace(
-    *obj: DataFrame[Any] | LazyFrame[Any] | Series[Any] | IntoFrame | IntoSeries,
-) -> Any:
+def get_native_namespace(*obj: Frame | Series[Any] | IntoFrame | IntoSeries) -> Any:
     """Get native namespace from object.
 
     Arguments:
@@ -607,28 +573,19 @@ def get_native_namespace(
 
 
 def _get_native_namespace_single_obj(
-    obj: DataFrame[Any] | LazyFrame[Any] | Series[Any] | IntoFrame | IntoSeries,
+    obj: Frame | Series[Any] | IntoFrame | IntoSeries,
 ) -> Any:
-    from contextlib import suppress
-
-    from narwhals._utils import has_native_namespace
-
-    with suppress(TypeError, AssertionError):
-        return Version.MAIN.namespace.from_native_object(
-            obj
-        ).implementation.to_native_namespace()
-
     if has_native_namespace(obj):
         return obj.__native_namespace__()
-    msg = f"Could not get native namespace from object of type: {type(obj)}"
-    raise TypeError(msg)
+    return Version.MAIN.namespace.from_native_object(
+        obj
+    ).implementation.to_native_namespace()
 
 
 def narwhalify(
     func: Callable[..., Any] | None = None,
     *,
-    strict: bool | None = None,
-    pass_through: bool | None = None,
+    pass_through: bool = True,
     eager_only: bool = False,
     series_only: bool = False,
     allow_series: bool | None = True,
@@ -645,20 +602,10 @@ def narwhalify(
 
     Arguments:
         func: Function to wrap in a `from_native`-`to_native` block.
-        strict: Determine what happens if the object can't be converted to Narwhals
-
-            *Deprecated* (v1.13.0)
-
-            Please use `pass_through` instead. Note that `strict` is still available
-            (and won't emit a deprecation warning) if you use `narwhals.stable.v1`,
-            see [perfect backwards compatibility policy](../backcompat.md/).
-
-            - `True` or `None` (default): raise an error
-            - `False`: pass object through as-is
         pass_through: Determine what happens if the object can't be converted to Narwhals
 
-            - `False` or `None` (default): raise an error
-            - `True`: pass object through as-is
+            - `False`: raise an error
+            - `True` (default): pass object through as-is
         eager_only: Whether to only allow eager objects
 
             - `False` (default): don't require `native_object` to be eager
@@ -690,11 +637,6 @@ def narwhalify(
         ... def agnostic_group_by_sum(df):
         ...     return df.group_by("a").agg(nw.col("b").sum())
     """
-    from narwhals._utils import validate_strict_and_pass_though
-
-    pass_through = validate_strict_and_pass_though(
-        strict, pass_through, pass_through_default=True, emit_deprecation_warning=True
-    )
 
     def decorator(func: Callable[..., Any]) -> Callable[..., Any]:
         @wraps(func)
@@ -739,9 +681,8 @@ def narwhalify(
 
     if func is None:
         return decorator
-    else:
-        # If func is not None, it means the decorator is used without arguments
-        return decorator(func)
+    # If func is not None, it means the decorator is used without arguments
+    return decorator(func)
 
 
 def to_py_scalar(scalar_like: Any) -> Any:
@@ -750,9 +691,6 @@ def to_py_scalar(scalar_like: Any) -> Any:
     Arguments:
         scalar_like: Scalar-like value.
 
-    Returns:
-        Python scalar.
-
     Raises:
         ValueError: If the object is not convertible to a scalar.
 
