@@ -13,6 +13,7 @@ from tests.utils import (
     Constructor,
     assert_equal_data,
     is_windows,
+    pyspark_session,
 )
 
 if TYPE_CHECKING:
@@ -153,17 +154,10 @@ def test_convert_time_zone_to_connection_tz_duckdb() -> None:
         )
 
 
-def test_convert_time_zone_to_connection_tz_pyspark(
-    constructor: Constructor,
-) -> None:  # pragma: no cover
-    if "pyspark" not in str(constructor) or "sqlframe" in str(constructor):
-        pytest.skip()
+def test_convert_time_zone_to_connection_tz_pyspark() -> None:  # pragma: no cover
     pytest.importorskip("pyspark")
-    from pyspark.sql import SparkSession
 
-    session = SparkSession.builder.config(
-        "spark.sql.session.timeZone", "UTC"
-    ).getOrCreate()
+    session = pyspark_session()
     df = nw.from_native(
         session.createDataFrame([(datetime(2020, 1, 1, tzinfo=timezone.utc),)], ["a"])
     )
