@@ -1,23 +1,15 @@
 from __future__ import annotations
 
 import narwhals as nw
-from tests.utils import Constructor
-from tests.utils import ConstructorEager
-from tests.utils import assert_equal_data
+from tests.utils import Constructor, ConstructorEager, assert_equal_data
 
-data = {
-    "a": [1.0, None, None, 3.0],
-    "b": [1.0, None, 4.0, 5.0],
-}
+data = {"a": [1.0, None, None, 3.0], "b": [1.0, None, 4.0, 5.0]}
 
 
 def test_null_count_expr(constructor: Constructor) -> None:
     df = nw.from_native(constructor(data))
     result = df.select(nw.col("a", "b").null_count())
-    expected = {
-        "a": [2],
-        "b": [1],
-    }
+    expected = {"a": [2], "b": [1]}
     assert_equal_data(result, expected)
 
 
